==> amazeui-vue-0.2.1.tgz: package/examples/public/app/7.app.js <==
webpackJsonp([7],{

/***/ 109:
/***/ function(module, exports, __webpack_require__) {

	module.exports = __webpack_require__(110)

	if (module.exports.__esModule) module.exports = module.exports.default
	;(typeof module.exports === "function" ? module.exports.options : module.exports).template = __webpack_require__(111)
	if (false) {
	(function () {
	var hotAPI = require("vue-hot-reload-api")
	hotAPI.install(require("vue"))
	if (!hotAPI.compatible) return
	var id = "-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./paginations.vue"
	hotAPI.createRecord(id, module.exports)
	module.hot.accept(["-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./paginations.vue","-!vue-html-loader!./../../../node_modules/vue-loader/lib/selector.js?type=template&index=0!./paginations.vue"], function () {
	var newOptions = require("-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./paginations.vue")
	if (newOptions && newOptions.__esModule) newOptions = newOptions.default
	var newTemplate = require("-!vue-html-loader!./../../../node_modules/vue-loader/lib/selector.js?type=template&index=0!./paginations.vue")
	hotAPI.update(id, newOptions, newTemplate)
	})
	})()
	}

/***/ },

/***/ 110:
/***/ function(module, exports) {

	'use strict';

	// <template>

	// <grid>

	//   <column :sm="12">

	//     <pagination :page="2" :total="10" :link="createLink" left></pagination>

	//   </column>

	//   <column :sm="12">

	//     <pagination :page="5" :total="10" :link="createLink" centered></pagination>

	//   </column>

	//   <column :sm="12">

	//     <pagination :page="8" :total="10" :link="createLink" right></pagination>

	//   </column>

	// </grid>

	// </template>

	// <script>

	module.exports = {

	  methods: {
	    createLink: function createLink(p) {
	      return '/paginations?page=' + p;
	    }
	  }
	};

	// </script>

/***/ },

/***/ 111:
/***/ function(module, exports) {

	module.exports = "<grid>\r\n  <column :sm=\"12\">\r\n    <pagination :page=\"2\" :total=\"10\" :link=\"createLink\" left></pagination>\r\n  </column>\r\n  <column :sm=\"12\">\r\n    <pagination :page=\"5\" :total=\"10\" :link=\"createLink\" centered></pagination>\r\n  </column>\r\n  <column :sm=\"12\">\r\n    <pagination :page=\"8\" :total=\"10\" :link=\"createLink\" right></pagination>\r\n  </column>\r\n</grid>";

/***/ }

});

==> amazeui-vue-0.2.4.tgz: package/examples/public/app/7.app.js <==
webpackJsonp([7],{

/***/ 109:
/***/ function(module, exports, __webpack_require__) {

	module.exports = __webpack_require__(110)

	if (module.exports.__esModule) module.exports = module.exports.default
	;(typeof module.exports === "function" ? module.exports.options : module.exports).template = __webpack_require__(111)
	if (false) {
	(function () {
	var hotAPI = require("vue-hot-reload-api")
	hotAPI.install(require("vue"))
	if (!hotAPI.compatible) return
	var id = "-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./paginations.vue"
	hotAPI.createRecord(id, module.exports)
	module.hot.accept(["-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./paginations.vue","-!vue-html-loader!./../../../node_modules/vue-loader/lib/selector.js?type=template&index=0!./paginations.vue"], function () {
	var newOptions = require("-!babel-loader?presets[]=es2015&plugins[]=transform-runtime!./../../../node_modules/vue-loader/lib/selector.js?type=script&index=0!./paginations.vue")
	if (newOptions && newOptions.__esModule) newOptions = newOptions.default
	var newTemplate = require("-!vue-html-loader!./../../../node_modules/vue-loader/lib/selector.js?type=template&index=0!./paginations.vue")
	hotAPI.update(id, newOptions, newTemplate)
	})
	})()
	}

/***/ },

/***/ 110:
/***/ function(module, exports) {

	'use strict';

	// <template>

	// <grid>

	//   <column v-bind:sm="12">

	//     <pagination v-bind:page="2" v-bind:total="10" v-bind:link="createLink" left></pagination>

	//   </column>

	//   <column v-bind:sm="12">

	//     <pagination v-bind:page="5" v-bind:total="10" v-bind:link="createLink" centered></pagination>

	//   </column>

	//   <column v-bind:sm="12">

	//     <pagination v-bind:page="8" v-bind:total="10" v-bind:link="createLink" right></pagination>

	//   </column>

	// </grid>

	// </template>

	// <script>

	module.exports = {

	  methods: {
	    createLink: function createLink(p) {
	      return '/paginations?page=' + p;
	    }
	  }
	};

	// </script>

/***/ },

/***/ 111:
/***/ function(module, exports) {

	module.exports = "<grid>\r\n  <column v-bind:sm=\"12\">\r\n    <pagination v-bind:page=\"2\" v-bind:total=\"10\" v-bind:link=\"createLink\" left></pagination>\r\n  </column>\r\n  <column v-bind:sm=\"12\">\r\n    <pagination v-bind:page=\"5\" v-bind:total=\"10\" v-bind:link=\"createLink\" centered></pagination>\r\n  </column>\r\n  <column v-bind:sm=\"12\">\r\n    <pagination v-bind:page=\"8\" v-bind:total=\"10\" v-bind:link=\"createLink\" right></pagination>\r\n  </column>\r\n</grid>";

/***/ }

});
